Prepend

Trait Prepend 

pub trait Prepend<T> {
    type Output;
}
Prepends a type T onto a tuple, producing a tuple one element larger.

Used by PathSpec to accumulate captured types from left to right as the HList is traversed.

Required Associated Types

type Output

The resulting tuple with T prepended.

Implementations on Foreign Types

Source

impl<T> Prepend<T> for ()

Source

impl<T, A> Prepend<T> for (A,)

Source

impl<T, A, B> Prepend<T> for (A, B)

Source

impl<T, A, B, C> Prepend<T> for (A, B, C)

Source

impl<T, A, B, C, D> Prepend<T> for (A, B, C, D)

Source

impl<T, A, B, C, D, E> Prepend<T> for (A, B, C, D, E)

Source

impl<T, A, B, C, D, E, F> Prepend<T> for (A, B, C, D, E, F)

Source

impl<T, A, B, C, D, E, F, G> Prepend<T> for (A, B, C, D, E, F, G)

Implementors