pub trait Prepend<T> {
type Output;
}Expand description
Prepends a type T onto a tuple, producing a tuple one element larger.
Used by PathSpec to accumulate captured types from left to right
as the HList is traversed.
pub trait Prepend<T> {
type Output;
}Prepends a type T onto a tuple, producing a tuple one element larger.
Used by PathSpec to accumulate captured types from left to right
as the HList is traversed.